@@ -6,11 +6,11 @@ Provides a client for DynamoDB.
 import logging
 
 import boto3
-from boto3.dynamodb.conditions import Attr
+
 from botocore.exceptions import ClientError
 
+
 log = logging.getLogger(__name__)
-log.setLevel(logging.INFO)
 
 
 class DynamoDBClient:
