@@ -6,7 +6,7 @@ parts.
 
 from dataclasses import InitVar, asdict, dataclass, field
 
-from ...exceptions import MalformedArnError
+from switchcraft.exceptions import MalformedArnError
 
 
 @dataclass
